###############################################################################
# Field Names
###############################################################################


COLLECTION = 'Collection'


###############################################################################
# Field Types
###############################################################################


TEXT = 'TEXT'


DATE = 'DATE'


INTEGER = 'INTEGER'


DECIMAL = 'DECIMAL'


DURATION = 'DURATION'


BOOLEAN = 'BOOLEAN'


SINGLE_OPTION = 'SINGLE_OPTION'


MULTIPLE_OPTION = 'MULTIPLE_OPTION'


###############################################################################
# Relationship Types
###############################################################################


ONE_TO_ONE = 'ONE_TO_ONE'


ONE_TO_MANY = 'ONE_TO_MANY'


MANY_TO_ONE = 'MANY_TO_ONE'


MANY_TO_MANY = 'MANY_TO_MANY'


###############################################################################
# GraphQL Error Codes
###############################################################################


GRAPHQL_VALIDATION_FAILED = 'GRAPHQL_VALIDATION_FAILED'
